"use strict";
var path_1 = require('path');
var fs_1 = require('fs');
var electron_1 = require('electron');
var mkdirp_1 = require('mkdirp');
var menu_1 = require('./menu');
if (process.argv.indexOf('--help') !== -1) {
    console.log("OVERVIEW: NyaoVim; Web-enhanced Extensible Neovim Frontend\n\nUSAGE: nyaovim [options] [neovim args...]\n\nOPTIONS:\n  --no-detach : Don't detach the editor process\n  --help      : Show this help\n  --version   : Show versions of NyaoVim, Electron, Chrome, Node.js, and V8\n");
    electron_1.app.quit();
}
if (process.argv.indexOf('--version') !== -1) {
    var vs_1 = process.versions;
    var versions = ['electron', 'chrome', 'node', 'v8'].map(function (n) { return ("  " + n + " : " + vs_1[n]); }).join('\n');
    console.log(electron_1.app.getName() + " version " + electron_1.app.getVersion() + "\n" + versions + "\n");
    electron_1.app.quit();
}
var config_dir_name = process.platform !== 'darwin' ?
    electron_1.app.getPath('appData') :
    process.env.XDG_CONFIG_HOME || path_1.join(process.env.HOME, '.config');
global.config_dir_path = path_1.join(config_dir_name, 'nyaovim');
global.nyaovimrc_path = path_1.join(global.config_dir_path, 'nyaovimrc.html');
function exists(path) {
    'use strict';
    return new Promise(function (resolve) {
        fs_1.stat(path, function (err, stats) {
            if (err) {
                return resolve(false);
            }
            return resolve(stats.isFile() || stats.isDirectory());
        });
    });
}
function prepareDefaultNyaovimrc() {
    'use strict';
    console.log('Generate default nyaovimrc at ' + global.nyaovimrc_path);
    return exists(global.config_dir_path).then(function (e) {
        if (!e) {
            mkdirp_1.sync(global.config_dir_path);
        }
    }).then(function () {
        var contents = "<dom-module id=\"nyaovim-app\">\n  <template>\n    <style>\n      /* CSS configurations here */\n    </style>\n\n    <!-- Component tags here -->\n    <neovim-editor id=\"nyaovim-editor\" argv$=\"[[argv]]\" font=\"monospace\"></neovim-editor>\n  </template>\n</dom-module>\n";
        fs_1.writeFileSync(global.nyaovimrc_path, contents, 'utf8');
    });
}
function isRunFromNpmPackage() {
    'use strict';
    return electron_1.app.getAppPath().indexOf('/NyaoVim.app/') === -1;
}
var ensure_nyaovimrc = exists(global.nyaovimrc_path).then(function (e) {
    if (!e) {
        return prepareDefaultNyaovimrc();
    }
}).catch(function (err) { return console.error(err); });
function startMainWindow() {
    'use strict';
    var index_html = 'file://' + path_1.join(__dirname, '..', 'renderer', 'main.html');
    var win = new electron_1.BrowserWindow({
        width: 800,
        height: 600,
        useContentSize: true,
        webPreferences: {
            blinkFeatures: 'KeyboardEventKey'
        },
    });
    win.once('closed', function () {
        win = null;
    });
    win.loadURL(index_html);
    if (process.env.NODE_ENV !== 'production') {
        win.webContents.openDevTools({ detach: true });
    }
}
electron_1.app.once('window-all-closed', function () { return electron_1.app.quit(); });
electron_1.app.on('open-url', function (e, u) {
    e.preventDefault();
    electron_1.shell.openExternal(u);
});
electron_1.app.once('ready', function () {
    if (process.platform === 'darwin' && isRunFromNpmPackage()) {
        electron_1.app.dock.setIcon(path_1.join(__dirname, '..', 'resources', 'icon', 'nyaovim-logo.png'));
    }
    ensure_nyaovimrc.then(function () { return startMainWindow(); });
    menu_1.default();
});
//# sourceMappingURL=main.js.map