"use strict";
var electron_1 = require('electron');
var path_1 = require('path');
var fs_1 = require('fs');
var app = electron_1.remote.require('app');
var ComponentLoader = (function () {
    function ComponentLoader() {
        this.initially_loaded = false;
        this.component_paths = [];
    }
    ComponentLoader.prototype.loadComponent = function (path) {
        var link = document.createElement('link');
        link.rel = 'import';
        link.href = path;
        document.head.appendChild(link);
        this.component_paths.push(path);
    };
    ComponentLoader.prototype.loadPluginDir = function (dir) {
        var nyaovim_plugin_dir = path_1.join(dir, 'nyaovim-plugin');
        try {
            for (var _i = 0, _a = fs_1.readdirSync(nyaovim_plugin_dir); _i < _a.length; _i++) {
                var entry = _a[_i];
                if (entry.endsWith('.html')) {
                    this.loadComponent(path_1.join(nyaovim_plugin_dir, entry));
                }
            }
            this.nyaovim_plugin_paths.push(dir);
        }
        catch (err) {
        }
    };
    ComponentLoader.prototype.loadFromRTP = function (runtimepaths) {
        for (var _i = 0, runtimepaths_1 = runtimepaths; _i < runtimepaths_1.length; _i++) {
            var rtp = runtimepaths_1[_i];
            this.loadPluginDir(rtp);
        }
    };
    return ComponentLoader;
}());
var RuntimeApi = (function () {
    function RuntimeApi(definitions) {
        this.definitions = definitions;
        this.client = null;
    }
    RuntimeApi.prototype.subscribe = function (client) {
        client.on('notification', this.call.bind(this));
        for (var name_1 in this.definitions) {
            client.subscribe(name_1);
        }
        this.client = client;
    };
    RuntimeApi.prototype.unsubscribe = function () {
        if (this.client) {
            for (var name_2 in this.definitions) {
                this.client.unsubscribe(name_2);
            }
        }
    };
    RuntimeApi.prototype.call = function (func_name, args) {
        var func = this.definitions[func_name];
        if (!func) {
            return null;
        }
        console.log('call(): ', func_name, args);
        return func.apply(func, args);
    };
    return RuntimeApi;
}());
var component_loader = new ComponentLoader();
var ThisBrowserWindow = electron_1.remote.getCurrentWindow();
var runtime_api = new RuntimeApi({
    'nyaovim:load-path': function (html_path) {
        component_loader.loadComponent(html_path);
    },
    'nyaovim:load-plugin-dir': function (dir_path) {
        component_loader.loadPluginDir(dir_path);
    },
    'nyaovim:edit-start': function (file_path) {
        ThisBrowserWindow.setRepresentedFilename(file_path);
        app.addRecentDocument(file_path);
    },
    'nyaovim:require-script-file': function (script_path) {
        require(script_path);
    },
    'nyaovim:call-global-function': function (func_name, args) {
        var func = window[func_name];
        if (func) {
            func.apply(window, args);
        }
    },
});
Polymer({
    is: 'nyaovim-app',
    properties: {
        argv: {
            type: Array,
            value: function () {
                var a = electron_1.remote.process.argv.slice(2);
                a.push('--cmd', "let g:nyaovim_version=\"" + app.getVersion() + "\"", '--cmd', "set rtp+=" + path_1.join(__dirname, '..', 'runtime').replace(' ', '\ '));
                a.push('-n');
                return a;
            },
        },
        editor: Object,
    },
    ready: function () {
        var element = document.getElementById('nyaovim-editor');
        var editor = element.editor;
        editor.on('error', function (err) { return alert(err.message); });
        editor.on('quit', function () { return ThisBrowserWindow.close(); });
        this.editor = editor;
        editor.store.on('beep', function () { return electron_1.shell.beep(); });
        editor.store.on('title-changed', function () {
            document.title = editor.store.title;
        });
        editor.on('process-attached', function () {
            var client = editor.getClient();
            client.listRuntimePaths()
                .then(function (rtp) {
                component_loader.loadFromRTP(rtp);
                component_loader.initially_loaded = true;
            });
            runtime_api.subscribe(client);
            element.addEventListener('drop', function (e) {
                e.preventDefault();
                var f = e.dataTransfer.files[0];
                if (f) {
                    client.command('edit! ' + f.path);
                }
            });
            app.on('open-file', function (e, p) {
                e.preventDefault();
                client.command('edit! ' + p);
            });
        });
        element.addEventListener('dragover', function (e) { return e.preventDefault(); });
        window.addEventListener('keydown', function (e) {
            if (e.keyCode === 0x1b && !editor.store.focused) {
                editor.focus();
            }
        });
    },
});
//# sourceMappingURL=nyaovim-app.js.map